@@ -21,6 +21,7 @@ import re
 from functools import partial
 import threading
 import serial
+from serial.tools import list_ports
 from serial import FIVEBITS, SIXBITS, SEVENBITS, EIGHTBITS
 from serial import PARITY_NONE, PARITY_EVEN, PARITY_ODD, PARITY_MARK, PARITY_SPACE
 from serial import STOPBITS_ONE, STOPBITS_ONE_POINT_FIVE, STOPBITS_TWO
@@ -343,7 +344,7 @@ class ExtensibleSerialInstrument(object):
         with self.communications_lock:
             success = False
             # Loop through serial ports, apparently 256 is the limit?!
-            for port_name, _, _ in serial.tools.list_ports.comports():
+            for port_name, _, _ in list_ports.comports():
                 try:
                     logging.info("Trying port {}".format(port_name))
                     self.open(port_name)
